==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/DoubleValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DoubleValueChangedEventArgsDescription } from "./DoubleValueChangedEventArgsDescription";
/**
 * @hidden
 */
var DoubleValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DoubleValueChangedEventArgsDescriptionMetadata, _super);
    function DoubleValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DoubleValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (DoubleValueChangedEventArgsDescriptionMetadata.a == null) {
            DoubleValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DoubleValueChangedEventArgsDescriptionMetadata.c(DoubleValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(DoubleValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(DoubleValueChangedEventArgsDescriptionMetadata.a);
    };
    DoubleValueChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("OldValue", "Number:double");
        a.item("NewValue", "Number:double");
    };
    DoubleValueChangedEventArgsDescriptionMetadata.d = function (a) {
        DoubleValueChangedEventArgsDescriptionMetadata.b(a);
        a.u("DoubleValueChangedEventArgs", function () { return new DoubleValueChangedEventArgsDescription(); });
        a.t("DoubleValueChangedEventArgs", DoubleValueChangedEventArgsDescriptionMetadata.a);
    };
    DoubleValueChangedEventArgsDescriptionMetadata.$t = markType(DoubleValueChangedEventArgsDescriptionMetadata, 'DoubleValueChangedEventArgsDescriptionMetadata');
    DoubleValueChangedEventArgsDescriptionMetadata.a = null;
    return DoubleValueChangedEventArgsDescriptionMetadata;
}(Base));
export { DoubleValueChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/DoubleValueChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DoubleValueChangedEventArgsDescription } from "./DoubleValueChangedEventArgsDescription";
/**
 * @hidden
 */
var DoubleValueChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(DoubleValueChangedEventArgsDescriptionMetadata, _super);
    function DoubleValueChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    DoubleValueChangedEventArgsDescriptionMetadata.b = function (a) {
        if (DoubleValueChangedEventArgsDescriptionMetadata.a == null) {
            DoubleValueChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            DoubleValueChangedEventArgsDescriptionMetadata.c(DoubleValueChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(DoubleValueChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(DoubleValueChangedEventArgsDescriptionMetadata.a);
    };
    DoubleValueChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("OldValue", "Number:double");
        a.item("NewValue", "Number:double");
    };
    DoubleValueChangedEventArgsDescriptionMetadata.d = function (a) {
        DoubleValueChangedEventArgsDescriptionMetadata.b(a);
        a.aa("DoubleValueChangedEventArgs", function () { return new DoubleValueChangedEventArgsDescription(); });
        a.z("DoubleValueChangedEventArgs", DoubleValueChangedEventArgsDescriptionMetadata.a);
    };
    DoubleValueChangedEventArgsDescriptionMetadata.$t = markType(DoubleValueChangedEventArgsDescriptionMetadata, 'DoubleValueChangedEventArgsDescriptionMetadata');
    DoubleValueChangedEventArgsDescriptionMetadata.a = null;
    return DoubleValueChangedEventArgsDescriptionMetadata;
}(Base));
export { DoubleValueChangedEventArgsDescriptionMetadata };
